@@ -35,6 +35,22 @@ static const uint PBOOK_HASH_BYTES = (PBOOK_HASH_BITS >> 3);
 typedef char compactBoardStr [36];
 
 
+PBook::~PBook ()
+{
+    bookNodeT * node;
+
+    for (uint i=0; i <= PBOOK_MAX_MATERIAL; i++) {
+        Tree[i]->IterateStart();
+        while ((node = Tree[i]->Iterate()) != NULL) {
+            delete[] node->data.comment;
+        }
+        delete Tree[i];
+    }
+    delete[] FileName;
+    delete[] HashFlags;
+    delete[] NodeList;
+}
+
 void
 PBook::SetHashFlag (Position * pos) {
     uint hash = PBOOK_HASH(pos);
@@ -275,9 +291,34 @@ PBook::FindNext (Position * pos, bool forwards)
         } while (NodeList[NextIndex] == NULL);
     }
 
-
     bookNodeT * node = NodeList[NextIndex];
-    ASSERT (node != NULL);
+    errorT err = pos->ReadFromCompactStr ((const byte *) node->name);
+    if (err != OK) { return err; }
+    pos->SetEPTarget (node->data.enpassant);
+
+    // Now print to FEN and re-read, to ensure the piece lists are in
+    // the order produced by a FEN specification -- this is necessary
+    // since a game with a specified start position has the piece lists
+    // in the FEN-generated order:
+
+    char temp[200];
+    pos->PrintFEN (temp, FEN_CASTLING_EP);
+    err = pos->ReadFromFEN (temp);
+    return err;
+}
+
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// PBook::FindByIndex():
+// Find a position by index and set it.
+errorT
+PBook::FindByIndex (Position * pos, uint idx)
+{
+    ASSERT (pos != NULL);
+    uint totalSize = Size();
+    if (totalSize == 0 || idx < 0 || idx >= NodeListCount) { return ERROR_NotFound; }
+    if (NodeList[idx] == NULL) { return ERROR_NotFound; }
+
+    bookNodeT * node = NodeList[idx];
     errorT err = pos->ReadFromCompactStr ((const byte *) node->name);
     if (err != OK) { return err; }
     pos->SetEPTarget (node->data.enpassant);
@@ -327,6 +368,32 @@ PBook::Insert (Position * pos, const char * comment)
     return err;
 }
 
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// PBook::SetIndex():
+//    Set the FindNext() index...
+int
+PBook::SetIndex (uint idx)
+{
+    if (idx < 0 || idx >= NodeListCount) { return -1; }
+    NextIndex = idx;
+    return NextIndex;
+}
+
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// PBook::GetIndex():
+//    Get the index into the node list for the given position.
+int
+PBook::GetIndex (Position * pos)
+{
+    uint material = pos->GetCount(WHITE) + pos->GetCount(BLACK);
+    compactBoardStr cboard;
+    pos->PrintCompactStr (cboard);
+    bookNodeT * node = Tree[material]->Lookup (cboard);
+    if (!node) return -1;
+    else return node->data.id;
+}
+
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // PBook::Delete():
 //    Delete a position from the PBook.
@@ -380,6 +447,32 @@ PBook::EcoSummary (const char * ecoPrefix, DString * dstr)
     }    
 }
 
+void
+PBook::EcoFind (const char * find, DString * dstr)
+{
+    // uint depth = strLength (ecoPrefix);
+    // const char * prevEcoStr = "";
+    for (uint i=0; i < NodeListCount; i++) {
+        bookNodeT * node = NodeList[i];
+        if (node == NULL) { continue; }
+        const char * comment = node->data.comment;
+        const char * ecoStr = epd_findOpcode (comment, "eco");
+        const char * movesStr = epd_findOpcode (comment, "moves");
+        if (ecoStr != NULL  &&  strContains (ecoStr,find)) {
+            while (*ecoStr != '\n'  &&  *ecoStr != 0) {
+                dstr->AddChar (*ecoStr);
+                ecoStr++;
+            }
+            dstr->Append ("  ");
+            while (*movesStr != '\n'  &&  *movesStr != 0) {
+                dstr->AddChar (*movesStr);
+                movesStr++;
+            }
+            dstr->AddChar ('\n');
+        }
+    }    
+}
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // PBook::StripOpcode:
 //    Strips the specified opcode from every position in the book.
@@ -425,11 +518,12 @@ PBook::StripOpcode (const char * opcode)
             while (*s != 0  &&  *s != '\n') { s++; }
             if (*s == '\n') { s++; }
             while (*s != 0) { dstr.AddChar (*s);  s++; }
-        delete[] node->data.comment;
+            delete[] node->data.comment;
             node->data.comment = strDuplicate (dstr.Data());
         }
     }
     delete[] searchCode;
+    if (countFound > 0) Altered = true;
     return countFound;
 }
 
