@@ -11,29 +11,8 @@ exec tclsh "$0" "$@"
 # Will remove a line containing the token in argument
 # NB - must be manually removed from english.tcl first.
 
-array set encodings {
-  czech iso8859-2
-  deutsch iso8859-1
-  francais iso8859-1
-  hungary iso8859-2
-  italian utf-8
-  nederlan iso8859-1
-  norsk iso8859-1
-  polish utf-8
-  portbr iso8859-1
-  port iso8859-1
-  russian utf-8
-  serbian iso8859-2
-  spanish iso8859-1
-  swedish iso8859-1
-  greek   utf-8
-}
+source langList.tcl
 
-set languages {czech deutsch francais hungary italian nederlan norsk polish
-  portbr port russian spanish swedish greek serbian
-}
-
-################################################################################
 proc remove {langfile enc token} {
   # Read the language file
 
