@@ -60,18 +60,28 @@ menuText S EditStripEnd "Movimientos hasta el final" 0 \
   {Quita los movimientos hasta el final de la partida}
 menuText S EditReset "Poner a cero la base de trabajo" 0 \
   {Pone a cero la base de trabajo (clipbase) para que est completamente vaca}
-menuText S EditCopy "Copiar esta partida a la base de trabajo" 1 \
-  {Copia esta partida a la base de trabajo (clipbase)}
-menuText S EditPaste "Pegar la ltima partida de la base de trabajo" 2 \
-  {Pega la partida activa en la base de trabajo (clipbase) aqu}
-menuText S EditPastePGN "Pegar el texto de la base de trabajo como partida PGN..." 10 \
-  {Interpreta el texto de la base de trabajo (clipbase) como una partida en notacion PGN y la pega aqu}
-menuText S EditSetup "Iniciar tablero de posicin..." 26 \
+# Benigno
+menuText S EditCopy "Copiar partida a Clipbase" 1 \
+  {Copia esta partida a Clipbase}
+# Benigno
+menuText S EditPaste "Pegar ltima partida de Clipbase" 2 \
+  {Pega la ltima partida de la Clipbase aqu}
+
+# Benigno
+menuText S EditPastePGN "Pegar texto como partida PGN..." 10 \
+  {Interpreta el texto del portapapeles como una partida en notacion PGN y la pega aqu}
+
+# Benigno
+menuText S EditSetup "Editar posicin..." 26 \
   {Inicia el tablero de posicin con la posicin de la partida}
+
 menuText S EditCopyBoard "Copiar posicin" 8 \
   {Copia el tablero actual en notacin FEN a la seleccin de texto (clipboard)}
-menuText S EditCopyPGN "Copiar PGN" 0 {}
-menuText S EditPasteBoard "Pegar tablero inicial" 6 \
+# Benigno
+menuText S EditCopyPGN "Copiar partida PGN" 0 {} 
+
+# Benigno
+menuText S EditPasteBoard "Pegar posicin" 6 \
   {Coloca el tablero inicial de la seleccin de texto actual (clipboard)}
 
 # Game menu:
@@ -104,8 +114,11 @@ menuText S GameNovelty "Encontrar novedad" 7 \
 
 # Search Menu:
 menuText S Search "Buscar" 0
-menuText S SearchReset "Poner a cero el filtro" 0 \
-  {Poner a cero el filtro para que todas la partidas estn incluidas}
+
+# Benigno
+menuText S SearchReset "Reiniciar el filtro" 0 \
+  {Eliminar el filtro para que todas la partidas estn incluidas}
+
 menuText S SearchNegate "Invertir filtro" 0 {Invierte el filtro para slo incluir las partidas excluidas}
 menuText S SearchEnd "Mover a ltimo filtro" 0
 menuText S SearchCurrent "Tablero actual..." 0 \
@@ -192,9 +205,6 @@ menuText S ToolsConnectHardware "Conectar hardware" 0 {Conectar  hardware extern
 menuText S ToolsConnectHardwareConfigure "Configurar..." 0 {Configurar conexin a hardware externo}
 menuText S ToolsConnectHardwareNovagCitrineConnect "Conectar Novag Citrine" 0 {Conectar Novag Citrine}
 menuText S ToolsConnectHardwareInputEngineConnect "Conectar Tablero" 0 {Conectar tablero de entra (p.ej. DGT)}
-menuText S ToolsNovagCitrine "Novag Citrine" 0 {Novag Citrine}
-menuText S ToolsNovagCitrineConfig "Configuracin" 0 {Configuracin Novag Citrine}
-menuText S ToolsNovagCitrineConnect "Conectar" 0 {Conectar Novag}
 menuText S ToolsPInfo "Informacin del jugador" 16 \
   {Abrir/actualizar la ventana de informacin del jugador}
 menuText S ToolsPlayerReport "Informe del jugador" 3 \
@@ -221,13 +231,15 @@ menuText S ToolsExpFilterHTML "Exportar filtro a HTML" 17 \
 menuText S ToolsExpFilterHTMLJS "Exportar filtro a HTML y JavaScript" 17 {Escribir todas las partidas filtradas a fichero HTML y JavaScript}  
 menuText S ToolsExpFilterLaTeX "Exportar filtro a LaTeX" 17 \
   {Escribe todas las partidas filtradas en un archivo LaTeX}
+# ====== TODO To be translated ======
+menuText S ToolsExpFilterEPD "Export Filter to EPD/FEN" 17 {Write all filtered games to an EPD File}
 menuText S ToolsExpFilterGames "Exportar Listado a Texto" 19 {Print a formatted Gamelist.}
 menuText S ToolsImportOne "Importar partida PGN" 0 \
   {Importa una partida de un texto PGN}
 menuText S ToolsImportFile "Importar archivo de partidas PGN" 2 \
   {Importa partidas de un archivo PGN}
-menuText S ToolsStartEngine1 "Arrancar motor 1" 0  {Arrancar motor 1}
-menuText S ToolsStartEngine2 "Arrancar motor 2" 0  {Arrancar Motor 2}
+menuText S ToolsStartEngine1 "Iniciar motor 1" 0  {Iniciar motor 1}
+menuText S ToolsStartEngine2 "Iniciar motor 2" 0  {Iniciar Motor 2}
 menuText S ToolsScreenshot "Captura de pantalla" 0
 menuText S Play "Jugar" 0
 menuText S CorrespondenceChess "Ajedrez por correo" 0 \
@@ -263,7 +275,16 @@ menuText S CCEditCopy "Copiar lista de partidas a clipbase" 0 \
 menuText S Options "Opciones" 0
 menuText S OptionsBoard "Tablero" 0 {Opciones sobre el aspecto del tablero}
 menuText S OptionsColour "Color de fondo" 0 {Color de fondo por defecto}
-menuText S OptionsEnableColour "Activar" 0 {}
+menuText S OptionsBackColour "Fondo" 0 {Color del widget de texto predeterminado}
+menuText S OptionsMainLineColour "Flechas principales" 0 {Flechas principales}
+menuText S OptionsVarLineColour "Flechas de variacin" 0 {Flechas de variacin}
+# ====== TODO To be translated ======
+menuText S OptionsEngineLineColour "Engine Arrows" 0 {Engine arrows}
+menuText S OptionsRowColour "Filas" 0 {Color predeterminado de la columna de rbol/libro}
+menuText S OptionsSwitcherColour "Conmutador" 0 {Color del conmutador db predeterminado}
+menuText S OptionsProgressColour "Barra de progreso" 0 {Color predeterminado de la barra de progreso}
+menuText S OptionsScoreColour "Grfico de puntuacin" 0 {}
+menuText S OptionsScoreBarColour "Grfico de puntuacin actual" 0 {}
 menuText S OptionsNames "Mis Nombres de Jugador" 3 {Edita mis nombres de jugador}
 menuText S OptionsExport "Exportacin" 0 {Cambia las opciones de exportacin de texto}
 menuText S OptionsFonts "Fuentes" 0 {Cambia las fuentes}
@@ -274,19 +295,23 @@ menuText S OptionsFontsFixed "Fijada" 0 {Cambia la anchura fijada de la fuente}
 menuText S OptionsGInfo "Informacin de la partida" 0 {Informacin de la partida}
 menuText S OptionsFics "FICS" 0
 menuText S OptionsFicsAuto "Autopromocin Reina" 0
+# ====== TODO To be translated ======
+menuText S OptionsFicsClk "Store Clock times" 0
 menuText S OptionsFicsColour "Color del texto" 0
 menuText S OptionsFicsSize "Tamao del Tablero" 0
+menuText S OptionsFicsButtons "Botones de usuario" 0
 menuText S OptionsFicsCommands "Comandos iniciales" 0
 menuText S OptionsFicsNoRes "Sin resultados" 0
 menuText S OptionsFicsNoReq "Sin respuesta" 0
-# ====== TODO To be translated ======
-menuText S OptionsFicsPremove "Allow Premove" 0
+menuText S OptionsFicsPremove "Permitir Pre-movimiento" 0
 menuText S OptionsLanguage "Lenguaje" 0 {Selecciona el lenguaje del men}
 menuText S OptionsMovesTranslatePieces "Traducir piezas" 0 {Traducir la primera letra de las piezas}
 menuText S OptionsMovesHighlightLastMove "Resalta ltima jugada" 0 {Resalta la ltima jugada}
 menuText S OptionsMovesHighlightLastMoveDisplay "Mostrar" 0 {Muestra la ltima jugada iluminada}
 menuText S OptionsMovesHighlightLastMoveWidth "Ancho" 0 {Espesor de la lnea}
 menuText S OptionsMovesHighlightLastMoveColor "Color" 0 {Color de lnea}
+# ====== TODO To be translated ======
+menuText S OptionsMovesColorSelected "Color Selected Square" 0 {Color move}
 menuText S OptionsMoves "Movimientos" 0 {Opciones de la entrada de movimientos}
 menuText S OptionsMovesAsk "Preguntar antes de reemplazar movimientos" 0 \
   {Pregunta antes de sobreescribir cualquier movimiento existente}
@@ -296,8 +321,6 @@ menuText S OptionsMovesDelay "Retardo del Automovimiento" 1 \
   {Pone el tiempo de demora para el modo de automovimiento}
 menuText S OptionsMovesCoord "Entrada de movimientos coordinada" 0 \
   {Acepta entrada de movimientos en sistema "coordinado" ("g1f3")}
-menuText S OptionsMovesSuggest "Mostrar movimientos sugeridos" 20 \
-  {Activa/desactiva la sugerencia de movimientos}
 menuText S OptionsShowVarPopup "Mostrar ventana de variaciones" 0 {Activa/desactivar la ventana de variaciones}
 menuText S OptionsMovesSpace "Aadir espacios detrs de nmero de jugada" 0 {Aadir espacios detrs del nmero de jugada}  
 menuText S OptionsMovesKey "Teclado inteligente" 0 \
@@ -335,8 +358,12 @@ menuText S OptionsRecent "Archivos recientes" 0 \
   {Cambia el nmero de archivos recientes mostrados en el men Archivo}
 menuText S OptionsBooksDir "Carpeta de libros de Aperturas (Books)" 0 {Fija la carpeta de los libros de aperturas (Books)}
 menuText S OptionsTacticsBasesDir "Carpeta de bases" 0 {Fija la carpeta de la base de entrenamiento tctico}
+menuText S OptionsInformant "Configurar valores de informacin" 0
 menuText S OptionsSave "Guardar opciones" 0 \
   "Guarda todas las opciones en el fichero $::optionsFile"
+
+menuText S OptionsSaveBases "Guardar bases por defecto" 0 
+
 menuText S OptionsAutoSave "Autoguardar opciones al salir" 0 \
   {Guarda automticamente todas las opciones cuando se sale de Scid}
 
@@ -367,13 +394,18 @@ menuText S GInfoTBResult  "TBs: slo resultado" 10
 menuText S GInfoTBAll "TBs: resultado y mejor movimiento" 23
 menuText S GInfoDelete "(No)Borrar esta partida" 4
 menuText S GInfoMark "(No)Marcar esta partida" 4
-menuText S GInfoInformant "Configurar valores de informacin" 0
+menuText S GInfoMenuBar "Barra de Mens"  0
+menuText S GInfoToolBar "Barra de Herramientas"  0
+menuText S GInfoButtonBar "Botn de Barra"  0
+menuText S GInfoStatusBar "Barra de Estado"  0
 
 translate S FlipBoard {Girar el tablero}
 translate S RaiseWindows {Aumentar ventanas}
 translate S AutoPlay {Reproduccin automtica}
 translate S TrialMode {Modo de prueba}
 
+translate S KeepOpen {Mantener abierto despus del inicio}
+
 # General buttons:
 translate S Apply {Aplicar}
 translate S Back {Atrs}
@@ -396,14 +428,14 @@ translate S MergeGames {Mezclar o fusionar partidas}
 translate S Preview {Vista previa}
 translate S Revert {Retroceder}
 translate S Save {Guardar}
-# ====== TODO To be translated ======
-translate S DontSave {Don't Save}
+translate S DontSave {No guardar}
 translate S Search {Buscar}
 translate S Stop {Parar}
 translate S Store {Almacenar}
 translate S Update {Actualizar}
 translate S ChangeOrient {Cambiar orientacin de la ventana}
 translate S ShowIcons {Mostrar iconos}
+translate S ConfirmCopy {Confirmar Copia}
 translate S None {Ninguno}
 translate S First {Primera}
 translate S Current {Actual}
@@ -458,16 +490,18 @@ translate S Database {Base de datos}
 translate S Filter {Filtro}
 translate S Reset {Reiniciar}
 translate S IgnoreCase {Ignorar el Asunto}
-translate S noGames {no hay partidas}
-translate S allGames {todas las partidas}
+translate S noGames {No hay partidas}
+translate S allGames {Todas las partidas}
 translate S empty {vaca}
 translate S clipbase {clipbase}
 translate S score {puntuacin}
-translate S Start {Posicin}
+translate S Start {Principio}
 translate S StartPos {Posicin inicial}
 translate S Total {Total}
 translate S readonly {slo lectura}
 translate S altered {alterado}
+translate S tagsDescript {Etiquetas adicionales (p.e.: Annotator "Anand")}
+translate S prevTags {Usar el anterior}
 
 # Standard error messages:
 translate S ErrNotOpen {Esta base de datos no est abierta.}
@@ -487,8 +521,8 @@ translate S GameEnd {Fin de partida}
 translate S LineEnd {Fin de lnea}
 
 # Player information:
-translate S PInfoAll {todas las partidas}
-translate S PInfoFilter {las partidas filtradas}
+translate S PInfoAll {Todas las partidas}
+translate S PInfoFilter {Las partidas filtradas}
 translate S PInfoAgainst {Resultados contra}
 translate S PInfoMostWhite {Aperturas ms comunes con Blancas}
 translate S PInfoMostBlack {Aperturas ms comunes con Negras}
@@ -501,6 +535,7 @@ translate S PinfoLookupName {Buscar nombre}
 # Tablebase information:
 translate S Draw {Tablas}
 translate S stalemate {rey ahogado}
+translate S checkmate {mate}
 translate S withAllMoves {con todos los movimientos}
 translate S withAllButOneMove {con todos los movimientos excepto uno}
 translate S with {con}
@@ -509,7 +544,6 @@ translate S lose {formas de perder}
 translate S loses {hace perder}
 translate S allOthersLose {todos los dems hacen perder}
 translate S matesIn {mate en}
-translate S hasCheckmated {jaque mate}
 translate S longest {el mate ms largo}
 translate S WinningMoves {Movimientos ganadores}
 translate S DrawingMoves {Movimientos para tablas}
@@ -526,7 +560,6 @@ menuText S TreeFileFillWithBase "Rellenar cach con base" 0 \
   {Rellena el archivo cach con todas las partidas de la base actual}
 menuText S TreeFileFillWithGame "Rellenar cach con partida" 0 \
   {Rellena el fichero cach con movimientos de la partida actual en la base actual}
-menuText S TreeFileSetCacheSize "Tamao de cach" 0 {Fija el tamao del cach}
 menuText S TreeFileCacheInfo "Informacin de cach" 0 \
   {Informacin y uso del cach}
 menuText S TreeFileSave "Guardar archivo cach" 0 \
@@ -574,14 +607,15 @@ menuText S TreeOptLock "Bloquear" 1 \
   {Bloquea/desbloquea el rbol de la base de datos actual}
 menuText S TreeOptTraining "Entrenamiento" 2 \
   {Activa/desactiva el modo de entrenamiento de rbol}
-# ====== TODO To be translated ======
-menuText S TreeOptShort "Short Display" 0 {Don't show ELO information}
+menuText S TreeOptShort "Pantalla corta" 0 {No mostrar informacin de ELO}
 menuText S TreeOptAutosave "Autoguardar archivo cach" 0 \
   {Guarda automticamente el archivo cach cuando se cierra la ventana de rbol}
 menuText S TreeOptAutomask "Carga automtica de mscara" 0 "Carga automtica de mscara con un arbol abierto."
+menuText S TreeOptCacheSize "Tamao de cach" 0 {Fija el tamao del cach}
 menuText S TreeOptShowBar "Mostrar barra de progreso" 0 "Mostrar barra de progreso del rbol"
 # ====== TODO To be translated ======
-menuText S TreeOptSortBest "Sort Best Games" 0 "Sort Best Games by ELO."
+menuText S TreeOptShowFrame "Show Button Bar" 0 "Show tree button bar."
+menuText S TreeOptSortBest "Ordenar mejores partidas" 0 "Ordenar mejores partidas por ELO."
 menuText S TreeHelp "Ayuda" 1
 menuText S TreeHelpTree "Ayuda del rbol" 4
 menuText S TreeHelpIndex "ndice de la ayuda" 0
@@ -597,7 +631,7 @@ translate S TreeAdjust {Ajustar filtro}
 # check the tree window to make sure it lines up with the actual columns.
 translate S TreeTitleRow {    Movim.    Frecuencia   Puntu. Tablas AvElo Perf AvAo ECO}
 translate S TreeTitleRowShort {    Movim.    Frecuencia   Puntu. Tablas}
-translate S TreeTotal {TOTAL}
+translate S TreeTotal: {TOTAL:}
 translate S DoYouWantToSaveFirst {Quieres salvar primero}
 translate S AddToMask {Aadir a mscara}
 translate S RemoveFromMask {Elimina desde la mscara}
@@ -626,7 +660,8 @@ translate S CommentMove {Comentar movimiento}
 translate S CommentPosition {Comentar posicin}
 translate S AddMoveToMaskFirst {Aadir primero el movimiento a la mscara}
 translate S OpenAMaskFileFirst {Abrir primero un fichero de mscara}
-translate S Positions {Posiciones}
+# ====== TODO To be translated ======
+translate S positions {positions}
 translate S Moves {Jugadas}
 
 # Finder window:
@@ -657,6 +692,8 @@ translate S FinderCtxBackup {Copia de seguridad (Backup)}
 translate S FinderCtxCopy {Copia}
 translate S FinderCtxMove {Jugada}
 translate S FinderCtxDelete {Borrar}
+# ====== TODO To be translated ======
+translate S FinderDirOpen {Open Directory}
 
 # Player finder:
 menuText S PListFile "Archivo" 0
@@ -693,6 +730,8 @@ menuText S GraphFileClose "Cerrar ventana" 0
 menuText S GraphOptions "Opciones" 0
 menuText S GraphOptionsWhite "Blancas" 0
 menuText S GraphOptionsBlack "Negras" 0
+menuText S GraphOptionsDots "Mostrar puntos" 0
+menuText S GraphOptionsBar "Destacar movimiento actual" 0
 menuText S GraphOptionsBoth "Ambos" 0
 menuText S GraphOptionsPInfo "Informacin jugador" 0
 translate S GraphFilterTitle "Filtro grfico: frecuencia por 1000 partidas"
@@ -710,25 +749,25 @@ translate S ShowAnalysisBoard {Mostrar tablero de anlisis}
 translate S ShowInfo {Muestra info del motor}
 translate S FinishGame {Finalizar partida}
 translate S StopEngine {Parar motor}
-translate S StartEngine {Arrancar motor}
+translate S StartEngine {Iniciar motor}
 translate S ExcludeMove {Excluir movimiento}
 translate S LockEngine {Bloquea motor en posicin actual}
 translate S AnalysisCommand {Direccin de anlisis}
 translate S PreviousChoices {Eleccin previa}
 translate S AnnotateTime {Segundos por movimiento}
-translate S AnnotateWhich {Qu Lado}
-translate S AnnotateAll {Movimientos por ambos Lados}
+translate S AnnotateWhich {Qu Lado?}
+translate S AnnotateAll {Movimientos de ambos Lados}
 translate S AnnotateAllMoves {Todos los movimientos}
-translate S AnnotateWhite {Slo movimientos de blancas}
-translate S AnnotateBlack {Slo movimientos de negras}
+translate S AnnotateWhite {Slo movimientos de las blancas}
+translate S AnnotateBlack {Slo movimientos de las negras}
 translate S AnnotateNotBest {Cuando el movimiento no es el mejor}
 translate S AnnotateBlundersOnly {Cuando el movimiento es un disparate}
-translate S BlundersNotBest {Errores/No Mejor}
-translate S AnnotateBlundersOnlyScoreChange {Anlisis reporta errores, con cambio de puntuacin desde: }
+translate S BlundersNotBest {Fallo/No Mejor}
 translate S AnnotateTitle {Configurar anotacin}
-translate S BlundersThreshold {Umbral del error }
+translate S AnnotateMissedMates {Mates omitidos/ms cortos}
+translate S BlundersThreshold {(Umbral)}
 translate S ScoreFormat {Formato de puntuacin}
-translate S CutOff {Punto de corte}
+translate S CutOff {Corte}
 translate S LowPriority {Baja prioridad del procesador}
 translate S LogEngines {Tamao del registro}
 translate S LogName {Aadir nombre}
@@ -744,6 +783,12 @@ translate S Informant+/- {Blancas tienen ventaja}
 translate S Informant+- {Blancas tienen una ventaja decisiva}
 translate S Informant++- {La partida es considerada ganada}
 translate S Book {Libro}
+# ====== TODO To be translated ======
+translate S OtherBook {Other Moves}
+# ====== TODO To be translated ======
+translate S Alphabetical {Alphabetical}
+# ====== TODO To be translated ======
+translate S TwoBooks {Two Books}
 
 # Analysis Engine open dialog:
 translate S EngineList {Lista de motores de anlisis}
@@ -810,7 +855,7 @@ menuText S CrosstabOpt "Opciones" 0
 menuText S CrosstabOptColorPlain "Texto simple" 0
 menuText S CrosstabOptColorHyper "Hipertexto" 0
 menuText S CrosstabOptTieWin "Desempate por victorias" 1
-menuText S CrosstabOptTieHead "Desempate por head-head" 1
+menuText S CrosstabOptTieHead "Desempate por head-to-head" 1
 menuText S CrosstabOptThreeWin "3 Puntos por victoria" 1
 menuText S CrosstabOptAges "Edad en aos" 1
 menuText S CrosstabOptNats "Nacionalidades" 0
@@ -820,6 +865,8 @@ menuText S CrosstabOptTitles "Ttulos" 0
 menuText S CrosstabOptBreaks "Puntuaciones de desempate" 0
 menuText S CrosstabOptDeleted "Incluir partidas borradas" 17
 menuText S CrosstabOptColors "Colores (slo en tabla de Suizos)" 0
+menuText S CrosstabOptColorRows "Filas de color" 0
+menuText S CrosstabOptRowsColor "Filas de tabla cruzada" 0 {Color predeterminado de fila de tabla cruzada}
 menuText S CrosstabOptColumnNumbers "Columnas numeradas (slo en tabla todos contra todos)" 11
 menuText S CrosstabOptGroup "Grupos de clasificacin" 0
 menuText S CrosstabSort "Ordenar" 0
@@ -863,6 +910,7 @@ translate S GameLength {Duracin:}
 translate S FindGamesWith {Encontrar partidas con}
 translate S StdStart {Inicio estndar}
 translate S Promotions {Promociones}
+translate S UnderPromo {Bajo promocin}
 translate S Comments {Comentarios}
 translate S Variations {Variaciones}
 translate S Annotations {Anotaciones}
@@ -880,6 +928,8 @@ translate S BrilliancyFlag {Genialidad}
 translate S BlunderFlag {Error}
 translate S UserFlag {Usuario}
 translate S PgnContains {PGN contiene texto}
+translate S PreComment {Comentario previo al juego}
+translate S PostComment {Fin del comentario} 
 
 # Game list window:
 translate S GlistNumber {Nmero}
@@ -897,7 +947,7 @@ translate S GlistResult {Resultado}
 translate S GlistLength {Longitud}
 translate S GlistCountry {Pas}
 translate S GlistECO {ECO}
-translate S GlistOpening {Apertura}
+translate S GlistOpening {Movimientos}
 translate S GlistEndMaterial {Material final}
 translate S GlistDeleted {Borrado}
 translate S GlistFlags {Seal}
@@ -1030,7 +1080,10 @@ translate S BoardSearch {Tablero de bsqueda}
 translate S FilterOperation {Operacin en filtro actual:}
 translate S FilterAnd {Y (Restringir filtro)}
 translate S FilterOr {O (Aadir al filtro)}
-translate S FilterIgnore {IGNORAR (Poner a cero el filtro)}
+
+# Benigno
+translate S FilterIgnore {IGNORAR (Reiniciar el filtro)}
+
 translate S SearchType {Tipo de bsqueda}
 translate S SearchBoardExact {Posicin exacta (todas las piezas en las mismas casillas)}
 translate S SearchBoardPawns {Peones (igual material, todos los peones en las mismas casillas)}
@@ -1038,6 +1091,9 @@ translate S SearchBoardFiles {Columnas (igual material, todos los peones en las
 translate S SearchBoardAny {Cualquiera (igual material, peones y piezas en cualquier parte)}
 translate S SearchInRefDatabase {Bsqueda en la base de referencia}
 translate S LookInVars {Mirar en variaciones}
+translate S CQLLabel {Bsqueda CQL}
+translate S CQLComments {Permite comentarios}
+translate S CQLStrip {Quita comentarios de la partida}
 
 # Material search:
 translate S MaterialSearch {Bsqueda de material}
@@ -1108,11 +1164,11 @@ translate S GoBack {Volver atrs}
 # Replace move dialog:
 translate S ReplaceMove {Reemplazar movimiento}
 translate S AddNewVar {Aadir nueva variacin}
-translate S NewMainLine {Nueva Lnea Principal}
+translate S NewMainLine {Nueva lnea principal}
 translate S ReplaceMoveMessage {Ya existe un movimiento.
 
-Por favor, entre eleccin
-Replazar movimiento descartar todos los movimientos posteriores}
+Por favor, seleccione su opcin
+La opcin Reemplazar movimiento eliminar todos los movimientos posteriores}
 
 # Make database read-only dialog:
 translate S ReadOnlyDialog {Si haces que esta base de datos sea de slo lectura no se permitirn hacer cambios. No se podrn guardar o reemplazar partidas, y no se podrn alterar las seales de borrada. Cualquier ordenacin o clasificacin por ECO ser temporal.
@@ -1123,9 +1179,14 @@ Realmente quieres hacer que esta base de datos sea de slo lectura?}
 
 # Exit dialog:
 translate S ExitDialog {Realmente quieres salir de Scid?}
+translate S ClearGameDialog {Esta partida ha sido alterada.\nDesea guardarla?}
+translate S ExitUnsaved {La siguiente base de datos tiene cambios en partidas no guardadas. Si sales ahora se perdern estos cambios.}
 # ====== TODO To be translated ======
-translate S ClearGameDialog {This game has been altered.\nDo you wish to save it?}
-translate S ExitUnsaved {La siguiente base de datos tiene cambios en partidas no guardados. Si sales ahora se perdern estos cambios.}
+translate S ChangeTextDialog {Enabling text colour globally requires restart.}
+# ====== TODO To be translated ======
+translate S ChangeDockDialog {Changing Docking requires a restart.}
+# ====== TODO To be translated ======
+translate S ExitNow {Exit now ?}
 
 # Import window:
 translate S PasteCurrentGame {Pegar partida actual}
@@ -1217,8 +1278,7 @@ translate S OprepViewLaTeX {Ver LaTeX}
 translate S PReportTitle {Informe del jugador}
 translate S PReportColorWhite {con las piezas blancas}
 translate S PReportColorBlack {con las piezas negras}
-# ====== TODO To be translated ======
-translate S PReportBeginning {Beginning with}
+translate S PReportBeginning {Empezando con}
 translate S PReportMoves {%s despus}
 translate S PReportOpenings {Aperturas}
 translate S PReportClipbase {Vaciar portapapeles y copiar las partidas}
@@ -1275,9 +1335,6 @@ translate S NameEditSelect {Partidas a editar}
 translate S NameEditReplace {Reemplazar}
 translate S NameEditWith {Con}
 translate S NameEditMatches {Partidas: Presionar Ctrl+1 a Ctrl+9 para seleccionarla}
-translate S CheckGamesWhich {Revisar partidas}
-translate S CheckAll {Todas las partidas}
-translate S CheckSelectFilterGames {Solo partidas en filtro}
 
 # Classify window:
 translate S Classify {Clasificar}
@@ -1300,7 +1357,7 @@ translate S CurrentState {Estado actual}
 translate S AfterCompaction {Despus de la compactacin}
 translate S CompactNames {Compactar archivo de nombres}
 translate S CompactGames {Compactar archivo de partidas}
-translate S NoUnusedNames "No hay nombres sin usar, por tanto el nombre del fichero est ya totalmente compactado."
+translate S NoUnusedNames "No hay nombres sin usar, por tanto, el fichero de nombres est ya totalmente compactado."
 translate S NoUnusedGames "El fichero ya est totalmente compactado."
 translate S NameFileCompacted {El fichero de nombre para la base de datos "[file tail [sc_base filename]]" fue compactado.}
 translate S GameFileCompacted {El fichero de partidas para la base de datos "[file tail [sc_base filename]]" fue compactado.}
@@ -1321,6 +1378,8 @@ translate S ExportColumnStyle {Estilo de columna (un movimiento por lnea)?}
 translate S ExportSymbolStyle {Estilo de anotacin simblico:}
 translate S ExportStripMarks {Quitar marca de cdigos de casilla/flecha de los comentarios?}
 
+translate S ExportFlags {Exportar Marcas de Scid}
+
 # Goto game/move dialogs:
 translate S LoadGameNumber {Entra el nmero de la partida a cargar:}
 translate S GotoMoveNumber {Ir al movimiento nmero:}
@@ -1343,7 +1402,6 @@ translate S CopyErrNotOpen {no est abierta}
 translate S LightSquares {Casillas claras}
 translate S DarkSquares {Casillas oscuras}
 translate S SelectedSquares {Casillas seleccionadas}
-translate S SuggestedSquares {Casillas de movimiento sugerido}
 translate S Grid {Cuadrcula}
 translate S Previous {Eleccin}
 translate S WhitePieces {Piezas blancas}
@@ -1352,6 +1410,8 @@ translate S WhiteBorder {Borde blancas}
 translate S BlackBorder {Borde negras}
 translate S ArrowMain   {Flecha lnea principal}
 translate S ArrowVar    {Flechas de variaciones}
+# ====== TODO To be translated ======
+translate S ShowArrows  {Show Arrows}
 
 # Novelty window:
 translate S FindNovelty {Encontrar novedad}
@@ -1483,12 +1543,20 @@ translate S FixedDepth {Profundidad fija}
 translate S Nodes {Nodos} 
 translate S Depth {Profundidad}
 translate S Time {Tiempo} 
+# ====== TODO To be translated ======
+translate S Auto {Auto}
+# ====== TODO To be translated ======
+translate S Score {Score}
+# ====== TODO To be translated ======
+translate S {Score Combo} {Score Combo}
+# ====== TODO To be translated ======
+translate S {Time Combo} {Time Combo}
 translate S SecondsPerMove {Segundos por movimiento}
 translate S DepthPerMove {Profundidad por movimiento}
 translate S MoveControl {Movimiento del control}
 translate S TimeLabel {Tiempo por movimiento}
 translate S AddVars {Aadir las variaciones}
-translate S AddScores {Aadir marcados}
+translate S AddScores {Aadir valoracin o puntuacin}
 translate S Engine {Motor}
 translate S TimeMode {Modo de tiempo}
 translate S TimeBonus {Tiempo + bonus}
@@ -1497,15 +1565,15 @@ translate S TimeSec {seg}
 translate S AllExercisesDone {Todos los ejercicio hechos}
 translate S MoveOutOfBook {Movimiento fuera del libro}
 translate S LastBookMove {ltimo movimiento del libro}
-translate S AnnotateSeveralGames {Anotar las partidas\ndesde la actual a: }
-translate S FindOpeningErrors {Solo errores de apertura}
+translate S AnnotateSeveralGames {Anotar las partidas\ndesde la actual a la: }
+translate S FindOpeningErrors {Solo errores de apertura en los primeros}
 translate S MarkTacticalExercises {Marca ejercicios tcticos}
 translate S UseBook {Usar libro de aperturas (Book)}
 translate S MultiPV {Variantes mltiples}
 translate S Hash {Memoria Hash}
 translate S OwnBook {Usar libro (book) del motor}
 translate S BookFile {Libro de aperturas}
-translate S AnnotateVariations {Procesar sub-variaciones}
+translate S AnnotateVariations {Procesar variantes}
 translate S ShortAnnotations {Anotaciones cortas}
 translate S addAnnotatorTag {Aadir etiqueta de anotador}
 translate S AddScoreToShortAnnotations {Aadir puntuacin para anotaciones cortas}
@@ -1584,6 +1652,8 @@ translate S FICSTimeseal {Timeseal}
 translate S FICSTimesealPort {Puerto Timeseal}
 translate S FICSSilence {Silencio}
 translate S FICSOffers {Ofertas}
+# ====== TODO To be translated ======
+translate S FICSMakeOffer {Make Offer}
 translate S FICSGames {Partidas}
 translate S FICSFindOpponent {Buscar oponente}
 translate S FICSTakeback {Retrocede}
@@ -1704,8 +1774,7 @@ translate S DockLeft {Mover a la izquierda}
 translate S DockRight {Mover a la derecha}
 translate S Undock {Ventana flotante}
 translate S ChangeIcon {Cambiar icono}
-# ====== TODO To be translated ======
-translate S More {More}
+translate S More {Ms}
 
 # Drag & Drop
 translate S CannotOpenUri {No se puede abrir la siguiente URI:}
@@ -1714,6 +1783,22 @@ translate S UriRejected	{Los siguientes archivos fueron rechazados:}
 translate S UriRejectedDetail {Slo pueden manejarse los tipos de archivo listados:}
 translate S EmptyUriList {Descartar. Contenido est vaco.}
 translate S SelectionOwnerDidntRespond {Tiempo excedido durante la operacin: el propietario de la seleccin no respondi.}
+# ====== TODO To be translated ======
+translate S PasteAnal {Paste Analysis}
+# ====== TODO To be translated ======
+translate S SortOpcodes {Sort Opcodes}
+# ====== TODO To be translated ======
+translate S AddPosition {Add Position}
+# ====== TODO To be translated ======
+translate S FindPos {Find Deepest Game Position}
+# ====== TODO To be translated ======
+translate S AnalPosition {Analyze Positions}
+# ====== TODO To be translated ======
+translate S StripOpcodes {Strip Opcodes}
+# ====== TODO To be translated ======
+translate S NoMoves {No moves from this position}
+# ====== TODO To be translated ======
+translate S CountBestMoves {Count Best Moves}
 
 }
 # end of spanish.tcl
